// This file was generated by qtwaylandscanner
// source file is treeland-output-manager-v1.xml

#ifndef QT_WAYLAND_TREELAND_OUTPUT_MANAGER_V1
#define QT_WAYLAND_TREELAND_OUTPUT_MANAGER_V1

#include "wayland-treeland-output-manager-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  treeland_output_manager_v1
    {
    public:
        treeland_output_manager_v1(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_output_manager_v1(struct ::treeland_output_manager_v1 *object);
        treeland_output_manager_v1();

        virtual ~treeland_output_manager_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_output_manager_v1 *object);

        struct ::treeland_output_manager_v1 *object() { return m_treeland_output_manager_v1; }
        const struct ::treeland_output_manager_v1 *object() const { return m_treeland_output_manager_v1; }
        static treeland_output_manager_v1 *fromObject(struct ::treeland_output_manager_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void set_primary_output(const QString &output);
        struct ::treeland_output_color_control_v1 *get_color_control(struct ::wl_output *output);
        void destroy();

    protected:
        virtual void treeland_output_manager_v1_primary_output(const QString &output_name);

    private:
        void init_listener();
        static const struct treeland_output_manager_v1_listener m_treeland_output_manager_v1_listener;
        static void handle_primary_output(
            void *data,
            struct ::treeland_output_manager_v1 *object,
            const char *output_name);
        struct ::treeland_output_manager_v1 *m_treeland_output_manager_v1;
    };

    class  treeland_output_color_control_v1
    {
    public:
        treeland_output_color_control_v1(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_output_color_control_v1(struct ::treeland_output_color_control_v1 *object);
        treeland_output_color_control_v1();

        virtual ~treeland_output_color_control_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_output_color_control_v1 *object);

        struct ::treeland_output_color_control_v1 *object() { return m_treeland_output_color_control_v1; }
        const struct ::treeland_output_color_control_v1 *object() const { return m_treeland_output_color_control_v1; }
        static treeland_output_color_control_v1 *fromObject(struct ::treeland_output_color_control_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_invalid_color_temperature = 1, // Invalid color temperature value provided.
            error_invalid_brightness = 2, // Invalid brightness value provided.
        };

        void set_color_temperature(uint32_t temperature);
        void set_brightness(wl_fixed_t brightness);
        void commit();
        void destroy();

    protected:
        virtual void treeland_output_color_control_v1_result(uint32_t success);
        virtual void treeland_output_color_control_v1_color_temperature(uint32_t temperature);
        virtual void treeland_output_color_control_v1_brightness(wl_fixed_t brightness);

    private:
        void init_listener();
        static const struct treeland_output_color_control_v1_listener m_treeland_output_color_control_v1_listener;
        static void handle_result(
            void *data,
            struct ::treeland_output_color_control_v1 *object,
            uint32_t success);
        static void handle_color_temperature(
            void *data,
            struct ::treeland_output_color_control_v1 *object,
            uint32_t temperature);
        static void handle_brightness(
            void *data,
            struct ::treeland_output_color_control_v1 *object,
            wl_fixed_t brightness);
        struct ::treeland_output_color_control_v1 *m_treeland_output_color_control_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
