/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.WallpaperSlideshow.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef WALLPAPERSLIDESHOWADAPTOR_H
#define WALLPAPERSLIDESHOWADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "wallpaperslideshow.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.deepin.dde.WallpaperSlideshow
 */
class WallpaperSlideshowAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.deepin.dde.WallpaperSlideshow")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.deepin.dde.WallpaperSlideshow\">\n"
"    <method name=\"GetWallpaperSlideShow\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"monitorName\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"slideShow\"/>\n"
"    </method>\n"
"    <method name=\"SetWallpaperSlideShow\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"monitorName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"slideShow\"/>\n"
"    </method>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"WallpaperSlideShow\"/>\n"
"  </interface>\n"
        "")
public:
    WallpaperSlideshowAdaptor(WallpaperSlideshow *parent);
    ~WallpaperSlideshowAdaptor() override;

    inline WallpaperSlideshow *parent() const
    { return static_cast<WallpaperSlideshow *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString WallpaperSlideShow READ wallpaperSlideShow WRITE setWallpaperSlideShow)
    QString wallpaperSlideShow() const;
    void setWallpaperSlideShow(const QString &value);

public Q_SLOTS: // METHODS
    QString GetWallpaperSlideShow(const QString &monitorName);
    void SetWallpaperSlideShow(const QString &monitorName, const QString &slideShow);
Q_SIGNALS: // SIGNALS
};

#endif
