// This file was generated by qtwaylandscanner
// source file is treeland-dde-shell-v1.xml

#include "qwayland-treeland-dde-shell-v1.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    treeland_dde_shell_manager_v1::treeland_dde_shell_manager_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_dde_shell_manager_v1::treeland_dde_shell_manager_v1(struct ::treeland_dde_shell_manager_v1 *obj)
        : m_treeland_dde_shell_manager_v1(obj)
    {
    }

    treeland_dde_shell_manager_v1::treeland_dde_shell_manager_v1()
        : m_treeland_dde_shell_manager_v1(nullptr)
    {
    }

    treeland_dde_shell_manager_v1::~treeland_dde_shell_manager_v1()
    {
    }

    void treeland_dde_shell_manager_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_dde_shell_manager_v1 = static_cast<struct ::treeland_dde_shell_manager_v1 *>(wlRegistryBind(registry, id, &treeland_dde_shell_manager_v1_interface, version));
    }

    void treeland_dde_shell_manager_v1::init(struct ::treeland_dde_shell_manager_v1 *obj)
    {
        m_treeland_dde_shell_manager_v1 = obj;
    }

    treeland_dde_shell_manager_v1 *treeland_dde_shell_manager_v1::fromObject(struct ::treeland_dde_shell_manager_v1 *object)
    {
        return static_cast<treeland_dde_shell_manager_v1 *>(treeland_dde_shell_manager_v1_get_user_data(object));
    }

    bool treeland_dde_shell_manager_v1::isInitialized() const
    {
        return m_treeland_dde_shell_manager_v1 != nullptr;
    }

    uint32_t treeland_dde_shell_manager_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_dde_shell_manager_v1));
    }

    const struct wl_interface *treeland_dde_shell_manager_v1::interface()
    {
        return &::treeland_dde_shell_manager_v1_interface;
    }

    struct ::treeland_window_overlap_checker *treeland_dde_shell_manager_v1::get_window_overlap_checker()
    {
        struct ::treeland_window_overlap_checker * id = ::treeland_dde_shell_manager_v1_get_window_overlap_checker(
            m_treeland_dde_shell_manager_v1);
        return id;
    }

    struct ::treeland_dde_shell_surface_v1 *treeland_dde_shell_manager_v1::get_shell_surface(struct ::wl_surface *surface)
    {
        struct ::treeland_dde_shell_surface_v1 * id = ::treeland_dde_shell_manager_v1_get_shell_surface(
            m_treeland_dde_shell_manager_v1,
            surface);
        return id;
    }

    struct ::treeland_dde_active_v1 *treeland_dde_shell_manager_v1::get_treeland_dde_active(struct ::wl_seat *seat)
    {
        struct ::treeland_dde_active_v1 * id = ::treeland_dde_shell_manager_v1_get_treeland_dde_active(
            m_treeland_dde_shell_manager_v1,
            seat);
        return id;
    }

    struct ::treeland_multitaskview_v1 *treeland_dde_shell_manager_v1::get_treeland_multitaskview()
    {
        struct ::treeland_multitaskview_v1 * id = ::treeland_dde_shell_manager_v1_get_treeland_multitaskview(
            m_treeland_dde_shell_manager_v1);
        return id;
    }

    struct ::treeland_window_picker_v1 *treeland_dde_shell_manager_v1::get_treeland_window_picker()
    {
        struct ::treeland_window_picker_v1 * id = ::treeland_dde_shell_manager_v1_get_treeland_window_picker(
            m_treeland_dde_shell_manager_v1);
        return id;
    }

    struct ::treeland_lockscreen_v1 *treeland_dde_shell_manager_v1::get_treeland_lockscreen()
    {
        struct ::treeland_lockscreen_v1 * id = ::treeland_dde_shell_manager_v1_get_treeland_lockscreen(
            m_treeland_dde_shell_manager_v1);
        return id;
    }

    struct ::wl_callback *treeland_dde_shell_manager_v1::set_xwindow_position_relative(uint32_t wid, struct ::wl_surface *anchor, wl_fixed_t dx, wl_fixed_t dy)
    {
        struct ::wl_callback * callback = ::treeland_dde_shell_manager_v1_set_xwindow_position_relative(
            m_treeland_dde_shell_manager_v1,
            wid,
            anchor,
            dx,
            dy);
        return callback;
    }

    void treeland_dde_shell_manager_v1::destroy()
    {
        ::treeland_dde_shell_manager_v1_destroy(
            m_treeland_dde_shell_manager_v1);
        m_treeland_dde_shell_manager_v1 = nullptr;
    }

    treeland_window_overlap_checker::treeland_window_overlap_checker(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_window_overlap_checker::treeland_window_overlap_checker(struct ::treeland_window_overlap_checker *obj)
        : m_treeland_window_overlap_checker(obj)
    {
        init_listener();
    }

    treeland_window_overlap_checker::treeland_window_overlap_checker()
        : m_treeland_window_overlap_checker(nullptr)
    {
    }

    treeland_window_overlap_checker::~treeland_window_overlap_checker()
    {
    }

    void treeland_window_overlap_checker::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_window_overlap_checker = static_cast<struct ::treeland_window_overlap_checker *>(wlRegistryBind(registry, id, &treeland_window_overlap_checker_interface, version));
        init_listener();
    }

    void treeland_window_overlap_checker::init(struct ::treeland_window_overlap_checker *obj)
    {
        m_treeland_window_overlap_checker = obj;
        init_listener();
    }

    treeland_window_overlap_checker *treeland_window_overlap_checker::fromObject(struct ::treeland_window_overlap_checker *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_treeland_window_overlap_checker_listener)
            return nullptr;
        return static_cast<treeland_window_overlap_checker *>(treeland_window_overlap_checker_get_user_data(object));
    }

    bool treeland_window_overlap_checker::isInitialized() const
    {
        return m_treeland_window_overlap_checker != nullptr;
    }

    uint32_t treeland_window_overlap_checker::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_window_overlap_checker));
    }

    const struct wl_interface *treeland_window_overlap_checker::interface()
    {
        return &::treeland_window_overlap_checker_interface;
    }

    void treeland_window_overlap_checker::update(int32_t width, int32_t height, uint32_t anchor, struct ::wl_output *output)
    {
        ::treeland_window_overlap_checker_update(
            m_treeland_window_overlap_checker,
            width,
            height,
            anchor,
            output);
    }

    void treeland_window_overlap_checker::destroy()
    {
        ::treeland_window_overlap_checker_destroy(
            m_treeland_window_overlap_checker);
        m_treeland_window_overlap_checker = nullptr;
    }

    void treeland_window_overlap_checker::treeland_window_overlap_checker_enter()
    {
    }

    void treeland_window_overlap_checker::handle_enter(
        void *data,
        struct ::treeland_window_overlap_checker *object)
    {
        Q_UNUSED(object);
        static_cast<treeland_window_overlap_checker *>(data)->treeland_window_overlap_checker_enter();
    }

    void treeland_window_overlap_checker::treeland_window_overlap_checker_leave()
    {
    }

    void treeland_window_overlap_checker::handle_leave(
        void *data,
        struct ::treeland_window_overlap_checker *object)
    {
        Q_UNUSED(object);
        static_cast<treeland_window_overlap_checker *>(data)->treeland_window_overlap_checker_leave();
    }

    const struct treeland_window_overlap_checker_listener treeland_window_overlap_checker::m_treeland_window_overlap_checker_listener = {
        treeland_window_overlap_checker::handle_enter,
        treeland_window_overlap_checker::handle_leave,
    };

    void treeland_window_overlap_checker::init_listener()
    {
        treeland_window_overlap_checker_add_listener(m_treeland_window_overlap_checker, &m_treeland_window_overlap_checker_listener, this);
    }

    treeland_dde_shell_surface_v1::treeland_dde_shell_surface_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_dde_shell_surface_v1::treeland_dde_shell_surface_v1(struct ::treeland_dde_shell_surface_v1 *obj)
        : m_treeland_dde_shell_surface_v1(obj)
    {
    }

    treeland_dde_shell_surface_v1::treeland_dde_shell_surface_v1()
        : m_treeland_dde_shell_surface_v1(nullptr)
    {
    }

    treeland_dde_shell_surface_v1::~treeland_dde_shell_surface_v1()
    {
    }

    void treeland_dde_shell_surface_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_dde_shell_surface_v1 = static_cast<struct ::treeland_dde_shell_surface_v1 *>(wlRegistryBind(registry, id, &treeland_dde_shell_surface_v1_interface, version));
    }

    void treeland_dde_shell_surface_v1::init(struct ::treeland_dde_shell_surface_v1 *obj)
    {
        m_treeland_dde_shell_surface_v1 = obj;
    }

    treeland_dde_shell_surface_v1 *treeland_dde_shell_surface_v1::fromObject(struct ::treeland_dde_shell_surface_v1 *object)
    {
        return static_cast<treeland_dde_shell_surface_v1 *>(treeland_dde_shell_surface_v1_get_user_data(object));
    }

    bool treeland_dde_shell_surface_v1::isInitialized() const
    {
        return m_treeland_dde_shell_surface_v1 != nullptr;
    }

    uint32_t treeland_dde_shell_surface_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_dde_shell_surface_v1));
    }

    const struct wl_interface *treeland_dde_shell_surface_v1::interface()
    {
        return &::treeland_dde_shell_surface_v1_interface;
    }

    void treeland_dde_shell_surface_v1::destroy()
    {
        ::treeland_dde_shell_surface_v1_destroy(
            m_treeland_dde_shell_surface_v1);
        m_treeland_dde_shell_surface_v1 = nullptr;
    }

    void treeland_dde_shell_surface_v1::set_surface_position(int32_t x, int32_t y)
    {
        ::treeland_dde_shell_surface_v1_set_surface_position(
            m_treeland_dde_shell_surface_v1,
            x,
            y);
    }

    void treeland_dde_shell_surface_v1::set_role(uint32_t role)
    {
        ::treeland_dde_shell_surface_v1_set_role(
            m_treeland_dde_shell_surface_v1,
            role);
    }

    void treeland_dde_shell_surface_v1::set_auto_placement(uint32_t y_offset)
    {
        ::treeland_dde_shell_surface_v1_set_auto_placement(
            m_treeland_dde_shell_surface_v1,
            y_offset);
    }

    void treeland_dde_shell_surface_v1::set_skip_switcher(uint32_t skip)
    {
        ::treeland_dde_shell_surface_v1_set_skip_switcher(
            m_treeland_dde_shell_surface_v1,
            skip);
    }

    void treeland_dde_shell_surface_v1::set_skip_dock_preview(uint32_t skip)
    {
        ::treeland_dde_shell_surface_v1_set_skip_dock_preview(
            m_treeland_dde_shell_surface_v1,
            skip);
    }

    void treeland_dde_shell_surface_v1::set_skip_muti_task_view(uint32_t skip)
    {
        ::treeland_dde_shell_surface_v1_set_skip_muti_task_view(
            m_treeland_dde_shell_surface_v1,
            skip);
    }

    void treeland_dde_shell_surface_v1::set_accept_keyboard_focus(uint32_t accept)
    {
        ::treeland_dde_shell_surface_v1_set_accept_keyboard_focus(
            m_treeland_dde_shell_surface_v1,
            accept);
    }

    treeland_dde_active_v1::treeland_dde_active_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_dde_active_v1::treeland_dde_active_v1(struct ::treeland_dde_active_v1 *obj)
        : m_treeland_dde_active_v1(obj)
    {
        init_listener();
    }

    treeland_dde_active_v1::treeland_dde_active_v1()
        : m_treeland_dde_active_v1(nullptr)
    {
    }

    treeland_dde_active_v1::~treeland_dde_active_v1()
    {
    }

    void treeland_dde_active_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_dde_active_v1 = static_cast<struct ::treeland_dde_active_v1 *>(wlRegistryBind(registry, id, &treeland_dde_active_v1_interface, version));
        init_listener();
    }

    void treeland_dde_active_v1::init(struct ::treeland_dde_active_v1 *obj)
    {
        m_treeland_dde_active_v1 = obj;
        init_listener();
    }

    treeland_dde_active_v1 *treeland_dde_active_v1::fromObject(struct ::treeland_dde_active_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_treeland_dde_active_v1_listener)
            return nullptr;
        return static_cast<treeland_dde_active_v1 *>(treeland_dde_active_v1_get_user_data(object));
    }

    bool treeland_dde_active_v1::isInitialized() const
    {
        return m_treeland_dde_active_v1 != nullptr;
    }

    uint32_t treeland_dde_active_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_dde_active_v1));
    }

    const struct wl_interface *treeland_dde_active_v1::interface()
    {
        return &::treeland_dde_active_v1_interface;
    }

    void treeland_dde_active_v1::destroy()
    {
        ::treeland_dde_active_v1_destroy(
            m_treeland_dde_active_v1);
        m_treeland_dde_active_v1 = nullptr;
    }

    void treeland_dde_active_v1::treeland_dde_active_v1_active_in(uint32_t )
    {
    }

    void treeland_dde_active_v1::handle_active_in(
        void *data,
        struct ::treeland_dde_active_v1 *object,
        uint32_t reason)
    {
        Q_UNUSED(object);
        static_cast<treeland_dde_active_v1 *>(data)->treeland_dde_active_v1_active_in(
            reason);
    }

    void treeland_dde_active_v1::treeland_dde_active_v1_active_out(uint32_t )
    {
    }

    void treeland_dde_active_v1::handle_active_out(
        void *data,
        struct ::treeland_dde_active_v1 *object,
        uint32_t reason)
    {
        Q_UNUSED(object);
        static_cast<treeland_dde_active_v1 *>(data)->treeland_dde_active_v1_active_out(
            reason);
    }

    void treeland_dde_active_v1::treeland_dde_active_v1_start_drag()
    {
    }

    void treeland_dde_active_v1::handle_start_drag(
        void *data,
        struct ::treeland_dde_active_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<treeland_dde_active_v1 *>(data)->treeland_dde_active_v1_start_drag();
    }

    void treeland_dde_active_v1::treeland_dde_active_v1_drop()
    {
    }

    void treeland_dde_active_v1::handle_drop(
        void *data,
        struct ::treeland_dde_active_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<treeland_dde_active_v1 *>(data)->treeland_dde_active_v1_drop();
    }

    const struct treeland_dde_active_v1_listener treeland_dde_active_v1::m_treeland_dde_active_v1_listener = {
        treeland_dde_active_v1::handle_active_in,
        treeland_dde_active_v1::handle_active_out,
        treeland_dde_active_v1::handle_start_drag,
        treeland_dde_active_v1::handle_drop,
    };

    void treeland_dde_active_v1::init_listener()
    {
        treeland_dde_active_v1_add_listener(m_treeland_dde_active_v1, &m_treeland_dde_active_v1_listener, this);
    }

    treeland_multitaskview_v1::treeland_multitaskview_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_multitaskview_v1::treeland_multitaskview_v1(struct ::treeland_multitaskview_v1 *obj)
        : m_treeland_multitaskview_v1(obj)
    {
    }

    treeland_multitaskview_v1::treeland_multitaskview_v1()
        : m_treeland_multitaskview_v1(nullptr)
    {
    }

    treeland_multitaskview_v1::~treeland_multitaskview_v1()
    {
    }

    void treeland_multitaskview_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_multitaskview_v1 = static_cast<struct ::treeland_multitaskview_v1 *>(wlRegistryBind(registry, id, &treeland_multitaskview_v1_interface, version));
    }

    void treeland_multitaskview_v1::init(struct ::treeland_multitaskview_v1 *obj)
    {
        m_treeland_multitaskview_v1 = obj;
    }

    treeland_multitaskview_v1 *treeland_multitaskview_v1::fromObject(struct ::treeland_multitaskview_v1 *object)
    {
        return static_cast<treeland_multitaskview_v1 *>(treeland_multitaskview_v1_get_user_data(object));
    }

    bool treeland_multitaskview_v1::isInitialized() const
    {
        return m_treeland_multitaskview_v1 != nullptr;
    }

    uint32_t treeland_multitaskview_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_multitaskview_v1));
    }

    const struct wl_interface *treeland_multitaskview_v1::interface()
    {
        return &::treeland_multitaskview_v1_interface;
    }

    void treeland_multitaskview_v1::destroy()
    {
        ::treeland_multitaskview_v1_destroy(
            m_treeland_multitaskview_v1);
        m_treeland_multitaskview_v1 = nullptr;
    }

    void treeland_multitaskview_v1::toggle()
    {
        ::treeland_multitaskview_v1_toggle(
            m_treeland_multitaskview_v1);
    }

    treeland_window_picker_v1::treeland_window_picker_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_window_picker_v1::treeland_window_picker_v1(struct ::treeland_window_picker_v1 *obj)
        : m_treeland_window_picker_v1(obj)
    {
        init_listener();
    }

    treeland_window_picker_v1::treeland_window_picker_v1()
        : m_treeland_window_picker_v1(nullptr)
    {
    }

    treeland_window_picker_v1::~treeland_window_picker_v1()
    {
    }

    void treeland_window_picker_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_window_picker_v1 = static_cast<struct ::treeland_window_picker_v1 *>(wlRegistryBind(registry, id, &treeland_window_picker_v1_interface, version));
        init_listener();
    }

    void treeland_window_picker_v1::init(struct ::treeland_window_picker_v1 *obj)
    {
        m_treeland_window_picker_v1 = obj;
        init_listener();
    }

    treeland_window_picker_v1 *treeland_window_picker_v1::fromObject(struct ::treeland_window_picker_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_treeland_window_picker_v1_listener)
            return nullptr;
        return static_cast<treeland_window_picker_v1 *>(treeland_window_picker_v1_get_user_data(object));
    }

    bool treeland_window_picker_v1::isInitialized() const
    {
        return m_treeland_window_picker_v1 != nullptr;
    }

    uint32_t treeland_window_picker_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_window_picker_v1));
    }

    const struct wl_interface *treeland_window_picker_v1::interface()
    {
        return &::treeland_window_picker_v1_interface;
    }

    void treeland_window_picker_v1::destroy()
    {
        ::treeland_window_picker_v1_destroy(
            m_treeland_window_picker_v1);
        m_treeland_window_picker_v1 = nullptr;
    }

    void treeland_window_picker_v1::pick(const QString &hint)
    {
        ::treeland_window_picker_v1_pick(
            m_treeland_window_picker_v1,
            hint.toUtf8().constData());
    }

    void treeland_window_picker_v1::treeland_window_picker_v1_window(int32_t )
    {
    }

    void treeland_window_picker_v1::handle_window(
        void *data,
        struct ::treeland_window_picker_v1 *object,
        int32_t pid)
    {
        Q_UNUSED(object);
        static_cast<treeland_window_picker_v1 *>(data)->treeland_window_picker_v1_window(
            pid);
    }

    const struct treeland_window_picker_v1_listener treeland_window_picker_v1::m_treeland_window_picker_v1_listener = {
        treeland_window_picker_v1::handle_window,
    };

    void treeland_window_picker_v1::init_listener()
    {
        treeland_window_picker_v1_add_listener(m_treeland_window_picker_v1, &m_treeland_window_picker_v1_listener, this);
    }

    treeland_lockscreen_v1::treeland_lockscreen_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_lockscreen_v1::treeland_lockscreen_v1(struct ::treeland_lockscreen_v1 *obj)
        : m_treeland_lockscreen_v1(obj)
    {
    }

    treeland_lockscreen_v1::treeland_lockscreen_v1()
        : m_treeland_lockscreen_v1(nullptr)
    {
    }

    treeland_lockscreen_v1::~treeland_lockscreen_v1()
    {
    }

    void treeland_lockscreen_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_lockscreen_v1 = static_cast<struct ::treeland_lockscreen_v1 *>(wlRegistryBind(registry, id, &treeland_lockscreen_v1_interface, version));
    }

    void treeland_lockscreen_v1::init(struct ::treeland_lockscreen_v1 *obj)
    {
        m_treeland_lockscreen_v1 = obj;
    }

    treeland_lockscreen_v1 *treeland_lockscreen_v1::fromObject(struct ::treeland_lockscreen_v1 *object)
    {
        return static_cast<treeland_lockscreen_v1 *>(treeland_lockscreen_v1_get_user_data(object));
    }

    bool treeland_lockscreen_v1::isInitialized() const
    {
        return m_treeland_lockscreen_v1 != nullptr;
    }

    uint32_t treeland_lockscreen_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_lockscreen_v1));
    }

    const struct wl_interface *treeland_lockscreen_v1::interface()
    {
        return &::treeland_lockscreen_v1_interface;
    }

    void treeland_lockscreen_v1::destroy()
    {
        ::treeland_lockscreen_v1_destroy(
            m_treeland_lockscreen_v1);
        m_treeland_lockscreen_v1 = nullptr;
    }

    void treeland_lockscreen_v1::lock()
    {
        ::treeland_lockscreen_v1_lock(
            m_treeland_lockscreen_v1);
    }

    void treeland_lockscreen_v1::shutdown()
    {
        ::treeland_lockscreen_v1_shutdown(
            m_treeland_lockscreen_v1);
    }

    void treeland_lockscreen_v1::switch_user()
    {
        ::treeland_lockscreen_v1_switch_user(
            m_treeland_lockscreen_v1);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
