// This file was generated by qtwaylandscanner
// source file is treeland-dde-shell-v1.xml

#ifndef QT_WAYLAND_TREELAND_DDE_SHELL_V1
#define QT_WAYLAND_TREELAND_DDE_SHELL_V1

#include "wayland-treeland-dde-shell-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  treeland_dde_shell_manager_v1
    {
    public:
        treeland_dde_shell_manager_v1(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_dde_shell_manager_v1(struct ::treeland_dde_shell_manager_v1 *object);
        treeland_dde_shell_manager_v1();

        virtual ~treeland_dde_shell_manager_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_dde_shell_manager_v1 *object);

        struct ::treeland_dde_shell_manager_v1 *object() { return m_treeland_dde_shell_manager_v1; }
        const struct ::treeland_dde_shell_manager_v1 *object() const { return m_treeland_dde_shell_manager_v1; }
        static treeland_dde_shell_manager_v1 *fromObject(struct ::treeland_dde_shell_manager_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        struct ::treeland_window_overlap_checker *get_window_overlap_checker();
        struct ::treeland_dde_shell_surface_v1 *get_shell_surface(struct ::wl_surface *surface);
        struct ::treeland_dde_active_v1 *get_treeland_dde_active(struct ::wl_seat *seat);
        struct ::treeland_multitaskview_v1 *get_treeland_multitaskview();
        struct ::treeland_window_picker_v1 *get_treeland_window_picker();
        struct ::treeland_lockscreen_v1 *get_treeland_lockscreen();
        struct ::wl_callback *set_xwindow_position_relative(uint32_t wid, struct ::wl_surface *anchor, wl_fixed_t dx, wl_fixed_t dy);
        void destroy();

    private:
        struct ::treeland_dde_shell_manager_v1 *m_treeland_dde_shell_manager_v1;
    };

    class  treeland_window_overlap_checker
    {
    public:
        treeland_window_overlap_checker(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_window_overlap_checker(struct ::treeland_window_overlap_checker *object);
        treeland_window_overlap_checker();

        virtual ~treeland_window_overlap_checker();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_window_overlap_checker *object);

        struct ::treeland_window_overlap_checker *object() { return m_treeland_window_overlap_checker; }
        const struct ::treeland_window_overlap_checker *object() const { return m_treeland_window_overlap_checker; }
        static treeland_window_overlap_checker *fromObject(struct ::treeland_window_overlap_checker *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum anchor {
            anchor_top = 1, // the top edge of the anchor rectangle
            anchor_bottom = 2, // the bottom edge of the anchor rectangle
            anchor_left = 4, // the left edge of the anchor rectangle
            anchor_right = 8, // the right edge of the anchor rectangle
        };

        void update(int32_t width, int32_t height, uint32_t anchor, struct ::wl_output *output);
        void destroy();

    protected:
        virtual void treeland_window_overlap_checker_enter();
        virtual void treeland_window_overlap_checker_leave();

    private:
        void init_listener();
        static const struct treeland_window_overlap_checker_listener m_treeland_window_overlap_checker_listener;
        static void handle_enter(
            void *data,
            struct ::treeland_window_overlap_checker *object);
        static void handle_leave(
            void *data,
            struct ::treeland_window_overlap_checker *object);
        struct ::treeland_window_overlap_checker *m_treeland_window_overlap_checker;
    };

    class  treeland_dde_shell_surface_v1
    {
    public:
        treeland_dde_shell_surface_v1(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_dde_shell_surface_v1(struct ::treeland_dde_shell_surface_v1 *object);
        treeland_dde_shell_surface_v1();

        virtual ~treeland_dde_shell_surface_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_dde_shell_surface_v1 *object);

        struct ::treeland_dde_shell_surface_v1 *object() { return m_treeland_dde_shell_surface_v1; }
        const struct ::treeland_dde_shell_surface_v1 *object() const { return m_treeland_dde_shell_surface_v1; }
        static treeland_dde_shell_surface_v1 *fromObject(struct ::treeland_dde_shell_surface_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum role {
            role_overlay = 1,
        };

        void destroy();
        void set_surface_position(int32_t x, int32_t y);
        void set_role(uint32_t role);
        void set_auto_placement(uint32_t y_offset);
        void set_skip_switcher(uint32_t skip);
        void set_skip_dock_preview(uint32_t skip);
        void set_skip_muti_task_view(uint32_t skip);
        void set_accept_keyboard_focus(uint32_t accept);

    private:
        struct ::treeland_dde_shell_surface_v1 *m_treeland_dde_shell_surface_v1;
    };

    class  treeland_dde_active_v1
    {
    public:
        treeland_dde_active_v1(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_dde_active_v1(struct ::treeland_dde_active_v1 *object);
        treeland_dde_active_v1();

        virtual ~treeland_dde_active_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_dde_active_v1 *object);

        struct ::treeland_dde_active_v1 *object() { return m_treeland_dde_active_v1; }
        const struct ::treeland_dde_active_v1 *object() const { return m_treeland_dde_active_v1; }
        static treeland_dde_active_v1 *fromObject(struct ::treeland_dde_active_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum reason {
            reason_mouse = 0,
            reason_wheel = 1,
        };

        void destroy();

    protected:
        virtual void treeland_dde_active_v1_active_in(uint32_t reason);
        virtual void treeland_dde_active_v1_active_out(uint32_t reason);
        virtual void treeland_dde_active_v1_start_drag();
        virtual void treeland_dde_active_v1_drop();

    private:
        void init_listener();
        static const struct treeland_dde_active_v1_listener m_treeland_dde_active_v1_listener;
        static void handle_active_in(
            void *data,
            struct ::treeland_dde_active_v1 *object,
            uint32_t reason);
        static void handle_active_out(
            void *data,
            struct ::treeland_dde_active_v1 *object,
            uint32_t reason);
        static void handle_start_drag(
            void *data,
            struct ::treeland_dde_active_v1 *object);
        static void handle_drop(
            void *data,
            struct ::treeland_dde_active_v1 *object);
        struct ::treeland_dde_active_v1 *m_treeland_dde_active_v1;
    };

    class  treeland_multitaskview_v1
    {
    public:
        treeland_multitaskview_v1(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_multitaskview_v1(struct ::treeland_multitaskview_v1 *object);
        treeland_multitaskview_v1();

        virtual ~treeland_multitaskview_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_multitaskview_v1 *object);

        struct ::treeland_multitaskview_v1 *object() { return m_treeland_multitaskview_v1; }
        const struct ::treeland_multitaskview_v1 *object() const { return m_treeland_multitaskview_v1; }
        static treeland_multitaskview_v1 *fromObject(struct ::treeland_multitaskview_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void destroy();
        void toggle();

    private:
        struct ::treeland_multitaskview_v1 *m_treeland_multitaskview_v1;
    };

    class  treeland_window_picker_v1
    {
    public:
        treeland_window_picker_v1(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_window_picker_v1(struct ::treeland_window_picker_v1 *object);
        treeland_window_picker_v1();

        virtual ~treeland_window_picker_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_window_picker_v1 *object);

        struct ::treeland_window_picker_v1 *object() { return m_treeland_window_picker_v1; }
        const struct ::treeland_window_picker_v1 *object() const { return m_treeland_window_picker_v1; }
        static treeland_window_picker_v1 *fromObject(struct ::treeland_window_picker_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void destroy();
        void pick(const QString &hint);

    protected:
        virtual void treeland_window_picker_v1_window(int32_t pid);

    private:
        void init_listener();
        static const struct treeland_window_picker_v1_listener m_treeland_window_picker_v1_listener;
        static void handle_window(
            void *data,
            struct ::treeland_window_picker_v1 *object,
            int32_t pid);
        struct ::treeland_window_picker_v1 *m_treeland_window_picker_v1;
    };

    class  treeland_lockscreen_v1
    {
    public:
        treeland_lockscreen_v1(struct ::wl_registry *registry, uint32_t id, int version);
        treeland_lockscreen_v1(struct ::treeland_lockscreen_v1 *object);
        treeland_lockscreen_v1();

        virtual ~treeland_lockscreen_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::treeland_lockscreen_v1 *object);

        struct ::treeland_lockscreen_v1 *object() { return m_treeland_lockscreen_v1; }
        const struct ::treeland_lockscreen_v1 *object() const { return m_treeland_lockscreen_v1; }
        static treeland_lockscreen_v1 *fromObject(struct ::treeland_lockscreen_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void destroy();
        void lock();
        void shutdown();
        void switch_user();

    private:
        struct ::treeland_lockscreen_v1 *m_treeland_lockscreen_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
