// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_appearancedbusproxy.cpp"
#include "WUWIAJYOSS/moc_backgrounds.cpp"
#include "EWIEGA46WW/moc_slideshowmanager.cpp"
#include "EWIEGA46WW/moc_wallpaperscheduler.cpp"
#include "EWIEGA46WW/moc_wallpaperslideshow.cpp"
